==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/ROUTEEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ROUTEEQUIPMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ROUTEEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTSEQUENCE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ROUTEEQUIPMENTID_Type", propOrder = {
    "routeid",
    "routeequipmentsequence"
})
public class ROUTEEQUIPMENTID_Type {

    @XmlElement(name = "ROUTEID", required = true)
    protected ROUTE_Type routeid;
    @XmlElement(name = "ROUTEEQUIPMENTSEQUENCE")
    protected long routeequipmentsequence;

    /**
     * Obtient la valeur de la propriété routeid.
     * 
     * @return
     *     possible object is
     *     {@link ROUTE_Type }
     *     
     */
    public ROUTE_Type getROUTEID() {
        return routeid;
    }

    /**
     * Définit la valeur de la propriété routeid.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTE_Type }
     *     
     */
    public void setROUTEID(ROUTE_Type value) {
        this.routeid = value;
    }

    /**
     * Obtient la valeur de la propriété routeequipmentsequence.
     * 
     */
    public long getROUTEEQUIPMENTSEQUENCE() {
        return routeequipmentsequence;
    }

    /**
     * Définit la valeur de la propriété routeequipmentsequence.
     * 
     */
    public void setROUTEEQUIPMENTSEQUENCE(long value) {
        this.routeequipmentsequence = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/ROUTEEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ROUTEEQUIPMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ROUTEEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTSEQUENCE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ROUTEEQUIPMENTID_Type", propOrder = {
    "routeid",
    "routeequipmentsequence"
})
public class ROUTEEQUIPMENTID_Type {

    @XmlElement(name = "ROUTEID", required = true)
    protected ROUTE_Type routeid;
    @XmlElement(name = "ROUTEEQUIPMENTSEQUENCE")
    protected long routeequipmentsequence;

    /**
     * Gets the value of the routeid property.
     * 
     * @return
     *     possible object is
     *     {@link ROUTE_Type }
     *     
     */
    public ROUTE_Type getROUTEID() {
        return routeid;
    }

    /**
     * Sets the value of the routeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTE_Type }
     *     
     */
    public void setROUTEID(ROUTE_Type value) {
        this.routeid = value;
    }

    /**
     * Gets the value of the routeequipmentsequence property.
     * 
     */
    public long getROUTEEQUIPMENTSEQUENCE() {
        return routeequipmentsequence;
    }

    /**
     * Sets the value of the routeequipmentsequence property.
     * 
     */
    public void setROUTEEQUIPMENTSEQUENCE(long value) {
        this.routeequipmentsequence = value;
    }

}
